Changelog
=========

All notable changes to openapi_builder will be documented here.

The format is based on `Keep a Changelog`_, and this project adheres to `Semantic Versioning`_.

.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html

Categories for changes are: Added, Changed, Deprecated, Removed, Fixed, Security.

Version `0.2.0 <https://github.com/FlyingBird95/openapi_builder/tree/v0.2.0>`__
--------------------------------------------------------------------------------

Introduced the following features:
- Changed interface to support the standard :code:`init_app` notation.
- Improved marshmallow support.
- Added :code:`custom_converters` option to :code:`add_documentation`.
- Added example.
- Added documentation.

Version `0.1.0 <https://github.com/FlyingBird95/openapi_builder/tree/v0.1.0>`__
--------------------------------------------------------------------------------

First release date: 2021-11-17.
Added setup for:
- Continuous integration (automated tests)
- Continuous delivery (publishing to PyPI)
- Automatically formatting (black and isort)
- Checking formatting errors (flake8)
- Automatic documentation integration and delivery
- Initial code
